# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_helper/api/logger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grpc_helper.api import common_pb2 as grpc__helper_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grpc_helper/api/logger.proto",
    package="",
    syntax="proto3",
    serialized_options=b"\n\017grpc_helper.apiP\001",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x1cgrpc_helper/api/logger.proto\x1a\x1cgrpc_helper/api/common.proto"J\n\x0cLoggerConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x1b\n\x05level\x18\x03 \x01(\x0e\x32\x0c.LoggerLevel"@\n\x0cLoggerStatus\x12\x12\n\x01r\x18\x01 \x01(\x0b\x32\x07.Result\x12\x1c\n\x05items\x18\x02 \x03(\x0b\x32\r.LoggerConfig",\n\x0cLoggerUpdate\x12\x1c\n\x05items\x18\x01 \x03(\x0b\x32\r.LoggerConfig*`\n\x10LoggerApiVersion\x12\x16\n\x12LOGGER_API_UNKNOWN\x10\x00\x12\x18\n\x14LOGGER_API_SUPPORTED\x10\x01\x12\x16\n\x12LOGGER_API_CURRENT\x10\x01\x1a\x02\x10\x01*m\n\x0bLoggerLevel\x12\x0f\n\x0bLVL_UNKNOWN\x10\x00\x12\r\n\tLVL_DEBUG\x10\n\x12\x0c\n\x08LVL_INFO\x10\x14\x12\x0f\n\x0bLVL_WARNING\x10\x1e\x12\r\n\tLVL_ERROR\x10(\x12\x10\n\x0cLVL_CRITICAL\x10\x32\x32t\n\rLoggerService\x12\x1d\n\x03get\x12\x07.Filter\x1a\r.LoggerStatus\x12\x1f\n\x05reset\x12\x07.Filter\x1a\r.LoggerStatus\x12#\n\x03set\x12\r.LoggerUpdate\x1a\r.LoggerStatusB\x13\n\x0fgrpc_helper.apiP\x01\x62\x06proto3',
    dependencies=[
        grpc__helper_dot_api_dot_common__pb2.DESCRIPTOR,
    ],
)

_LOGGERAPIVERSION = _descriptor.EnumDescriptor(
    name="LoggerApiVersion",
    full_name="LoggerApiVersion",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="LOGGER_API_UNKNOWN", index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="LOGGER_API_SUPPORTED", index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="LOGGER_API_CURRENT", index=2, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=b"\020\001",
    serialized_start=250,
    serialized_end=346,
)
_sym_db.RegisterEnumDescriptor(_LOGGERAPIVERSION)

LoggerApiVersion = enum_type_wrapper.EnumTypeWrapper(_LOGGERAPIVERSION)
_LOGGERLEVEL = _descriptor.EnumDescriptor(
    name="LoggerLevel",
    full_name="LoggerLevel",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(name="LVL_UNKNOWN", index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(name="LVL_DEBUG", index=1, number=10, serialized_options=None, type=None, create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(name="LVL_INFO", index=2, number=20, serialized_options=None, type=None, create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
            name="LVL_WARNING", index=3, number=30, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(name="LVL_ERROR", index=4, number=40, serialized_options=None, type=None, create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
            name="LVL_CRITICAL", index=5, number=50, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=348,
    serialized_end=457,
)
_sym_db.RegisterEnumDescriptor(_LOGGERLEVEL)

LoggerLevel = enum_type_wrapper.EnumTypeWrapper(_LOGGERLEVEL)
LOGGER_API_UNKNOWN = 0
LOGGER_API_SUPPORTED = 1
LOGGER_API_CURRENT = 1
LVL_UNKNOWN = 0
LVL_DEBUG = 10
LVL_INFO = 20
LVL_WARNING = 30
LVL_ERROR = 40
LVL_CRITICAL = 50


_LOGGERCONFIG = _descriptor.Descriptor(
    name="LoggerConfig",
    full_name="LoggerConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="LoggerConfig.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enabled",
            full_name="LoggerConfig.enabled",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="level",
            full_name="LoggerConfig.level",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=62,
    serialized_end=136,
)


_LOGGERSTATUS = _descriptor.Descriptor(
    name="LoggerStatus",
    full_name="LoggerStatus",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="r",
            full_name="LoggerStatus.r",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="items",
            full_name="LoggerStatus.items",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=138,
    serialized_end=202,
)


_LOGGERUPDATE = _descriptor.Descriptor(
    name="LoggerUpdate",
    full_name="LoggerUpdate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="items",
            full_name="LoggerUpdate.items",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=204,
    serialized_end=248,
)

_LOGGERCONFIG.fields_by_name["level"].enum_type = _LOGGERLEVEL
_LOGGERSTATUS.fields_by_name["r"].message_type = grpc__helper_dot_api_dot_common__pb2._RESULT
_LOGGERSTATUS.fields_by_name["items"].message_type = _LOGGERCONFIG
_LOGGERUPDATE.fields_by_name["items"].message_type = _LOGGERCONFIG
DESCRIPTOR.message_types_by_name["LoggerConfig"] = _LOGGERCONFIG
DESCRIPTOR.message_types_by_name["LoggerStatus"] = _LOGGERSTATUS
DESCRIPTOR.message_types_by_name["LoggerUpdate"] = _LOGGERUPDATE
DESCRIPTOR.enum_types_by_name["LoggerApiVersion"] = _LOGGERAPIVERSION
DESCRIPTOR.enum_types_by_name["LoggerLevel"] = _LOGGERLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoggerConfig = _reflection.GeneratedProtocolMessageType(
    "LoggerConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOGGERCONFIG,
        "__module__": "grpc_helper.api.logger_pb2"
        # @@protoc_insertion_point(class_scope:LoggerConfig)
    },
)
_sym_db.RegisterMessage(LoggerConfig)

LoggerStatus = _reflection.GeneratedProtocolMessageType(
    "LoggerStatus",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOGGERSTATUS,
        "__module__": "grpc_helper.api.logger_pb2"
        # @@protoc_insertion_point(class_scope:LoggerStatus)
    },
)
_sym_db.RegisterMessage(LoggerStatus)

LoggerUpdate = _reflection.GeneratedProtocolMessageType(
    "LoggerUpdate",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOGGERUPDATE,
        "__module__": "grpc_helper.api.logger_pb2"
        # @@protoc_insertion_point(class_scope:LoggerUpdate)
    },
)
_sym_db.RegisterMessage(LoggerUpdate)


DESCRIPTOR._options = None
_LOGGERAPIVERSION._options = None

_LOGGERSERVICE = _descriptor.ServiceDescriptor(
    name="LoggerService",
    full_name="LoggerService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=459,
    serialized_end=575,
    methods=[
        _descriptor.MethodDescriptor(
            name="get",
            full_name="LoggerService.get",
            index=0,
            containing_service=None,
            input_type=grpc__helper_dot_api_dot_common__pb2._FILTER,
            output_type=_LOGGERSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="reset",
            full_name="LoggerService.reset",
            index=1,
            containing_service=None,
            input_type=grpc__helper_dot_api_dot_common__pb2._FILTER,
            output_type=_LOGGERSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="set",
            full_name="LoggerService.set",
            index=2,
            containing_service=None,
            input_type=_LOGGERUPDATE,
            output_type=_LOGGERSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_LOGGERSERVICE)

DESCRIPTOR.services_by_name["LoggerService"] = _LOGGERSERVICE

# @@protoc_insertion_point(module_scope)
