# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_helper/api/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grpc_helper.api import common_pb2 as grpc__helper_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grpc_helper/api/config.proto",
    package="",
    syntax="proto3",
    serialized_options=b"\n\017grpc_helper.apiP\001",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x1cgrpc_helper/api/config.proto\x1a\x1cgrpc_helper/api/common.proto"\x90\x01\n\nConfigItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61n_be_empty\x18\x05 \x01(\x08\x12#\n\tvalidator\x18\x06 \x01(\x0e\x32\x10.ConfigValidator">\n\x0c\x43onfigStatus\x12\x12\n\x01r\x18\x01 \x01(\x0b\x32\x07.Result\x12\x1a\n\x05items\x18\x02 \x03(\x0b\x32\x0b.ConfigItem"/\n\x10\x43onfigItemUpdate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"H\n\x0c\x43onfigUpdate\x12 \n\x05items\x18\x01 \x03(\x0b\x32\x11.ConfigItemUpdate\x12\x16\n\x0eignore_unknown\x18\x02 \x01(\x08*\\\n\x10\x43onfigApiVersion\x12\x16\n\x12\x43ONFIG_API_UNKNOWN\x10\x00\x12\x18\n\x14\x43ONFIG_API_SUPPORTED\x10\x01\x12\x16\n\x12\x43ONFIG_API_CURRENT\x10\x02*\xa7\x01\n\x0f\x43onfigValidator\x12\x17\n\x13\x43ONFIG_VALID_STRING\x10\x00\x12\x17\n\x13\x43ONFIG_VALID_CUSTOM\x10\x01\x12\x14\n\x10\x43ONFIG_VALID_INT\x10\x02\x12\x18\n\x14\x43ONFIG_VALID_POS_INT\x10\x03\x12\x16\n\x12\x43ONFIG_VALID_FLOAT\x10\x04\x12\x1a\n\x16\x43ONFIG_VALID_POS_FLOAT\x10\x05\x32t\n\rConfigService\x12\x1d\n\x03get\x12\x07.Filter\x1a\r.ConfigStatus\x12\x1f\n\x05reset\x12\x07.Filter\x1a\r.ConfigStatus\x12#\n\x03set\x12\r.ConfigUpdate\x1a\r.ConfigStatusB\x13\n\x0fgrpc_helper.apiP\x01\x62\x06proto3',
    dependencies=[
        grpc__helper_dot_api_dot_common__pb2.DESCRIPTOR,
    ],
)

_CONFIGAPIVERSION = _descriptor.EnumDescriptor(
    name="ConfigApiVersion",
    full_name="ConfigApiVersion",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONFIG_API_UNKNOWN", index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_API_SUPPORTED", index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_API_CURRENT", index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=396,
    serialized_end=488,
)
_sym_db.RegisterEnumDescriptor(_CONFIGAPIVERSION)

ConfigApiVersion = enum_type_wrapper.EnumTypeWrapper(_CONFIGAPIVERSION)
_CONFIGVALIDATOR = _descriptor.EnumDescriptor(
    name="ConfigValidator",
    full_name="ConfigValidator",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONFIG_VALID_STRING", index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_VALID_CUSTOM", index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_VALID_INT", index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_VALID_POS_INT", index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_VALID_FLOAT", index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="CONFIG_VALID_POS_FLOAT", index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=491,
    serialized_end=658,
)
_sym_db.RegisterEnumDescriptor(_CONFIGVALIDATOR)

ConfigValidator = enum_type_wrapper.EnumTypeWrapper(_CONFIGVALIDATOR)
CONFIG_API_UNKNOWN = 0
CONFIG_API_SUPPORTED = 1
CONFIG_API_CURRENT = 2
CONFIG_VALID_STRING = 0
CONFIG_VALID_CUSTOM = 1
CONFIG_VALID_INT = 2
CONFIG_VALID_POS_INT = 3
CONFIG_VALID_FLOAT = 4
CONFIG_VALID_POS_FLOAT = 5


_CONFIGITEM = _descriptor.Descriptor(
    name="ConfigItem",
    full_name="ConfigItem",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="ConfigItem.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="ConfigItem.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="ConfigItem.value",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_value",
            full_name="ConfigItem.default_value",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="can_be_empty",
            full_name="ConfigItem.can_be_empty",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validator",
            full_name="ConfigItem.validator",
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=63,
    serialized_end=207,
)


_CONFIGSTATUS = _descriptor.Descriptor(
    name="ConfigStatus",
    full_name="ConfigStatus",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="r",
            full_name="ConfigStatus.r",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="items",
            full_name="ConfigStatus.items",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=209,
    serialized_end=271,
)


_CONFIGITEMUPDATE = _descriptor.Descriptor(
    name="ConfigItemUpdate",
    full_name="ConfigItemUpdate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="ConfigItemUpdate.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="ConfigItemUpdate.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=273,
    serialized_end=320,
)


_CONFIGUPDATE = _descriptor.Descriptor(
    name="ConfigUpdate",
    full_name="ConfigUpdate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="items",
            full_name="ConfigUpdate.items",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ignore_unknown",
            full_name="ConfigUpdate.ignore_unknown",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=322,
    serialized_end=394,
)

_CONFIGITEM.fields_by_name["validator"].enum_type = _CONFIGVALIDATOR
_CONFIGSTATUS.fields_by_name["r"].message_type = grpc__helper_dot_api_dot_common__pb2._RESULT
_CONFIGSTATUS.fields_by_name["items"].message_type = _CONFIGITEM
_CONFIGUPDATE.fields_by_name["items"].message_type = _CONFIGITEMUPDATE
DESCRIPTOR.message_types_by_name["ConfigItem"] = _CONFIGITEM
DESCRIPTOR.message_types_by_name["ConfigStatus"] = _CONFIGSTATUS
DESCRIPTOR.message_types_by_name["ConfigItemUpdate"] = _CONFIGITEMUPDATE
DESCRIPTOR.message_types_by_name["ConfigUpdate"] = _CONFIGUPDATE
DESCRIPTOR.enum_types_by_name["ConfigApiVersion"] = _CONFIGAPIVERSION
DESCRIPTOR.enum_types_by_name["ConfigValidator"] = _CONFIGVALIDATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigItem = _reflection.GeneratedProtocolMessageType(
    "ConfigItem",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONFIGITEM,
        "__module__": "grpc_helper.api.config_pb2"
        # @@protoc_insertion_point(class_scope:ConfigItem)
    },
)
_sym_db.RegisterMessage(ConfigItem)

ConfigStatus = _reflection.GeneratedProtocolMessageType(
    "ConfigStatus",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONFIGSTATUS,
        "__module__": "grpc_helper.api.config_pb2"
        # @@protoc_insertion_point(class_scope:ConfigStatus)
    },
)
_sym_db.RegisterMessage(ConfigStatus)

ConfigItemUpdate = _reflection.GeneratedProtocolMessageType(
    "ConfigItemUpdate",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONFIGITEMUPDATE,
        "__module__": "grpc_helper.api.config_pb2"
        # @@protoc_insertion_point(class_scope:ConfigItemUpdate)
    },
)
_sym_db.RegisterMessage(ConfigItemUpdate)

ConfigUpdate = _reflection.GeneratedProtocolMessageType(
    "ConfigUpdate",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONFIGUPDATE,
        "__module__": "grpc_helper.api.config_pb2"
        # @@protoc_insertion_point(class_scope:ConfigUpdate)
    },
)
_sym_db.RegisterMessage(ConfigUpdate)


DESCRIPTOR._options = None

_CONFIGSERVICE = _descriptor.ServiceDescriptor(
    name="ConfigService",
    full_name="ConfigService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=660,
    serialized_end=776,
    methods=[
        _descriptor.MethodDescriptor(
            name="get",
            full_name="ConfigService.get",
            index=0,
            containing_service=None,
            input_type=grpc__helper_dot_api_dot_common__pb2._FILTER,
            output_type=_CONFIGSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="reset",
            full_name="ConfigService.reset",
            index=1,
            containing_service=None,
            input_type=grpc__helper_dot_api_dot_common__pb2._FILTER,
            output_type=_CONFIGSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="set",
            full_name="ConfigService.set",
            index=2,
            containing_service=None,
            input_type=_CONFIGUPDATE,
            output_type=_CONFIGSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_CONFIGSERVICE)

DESCRIPTOR.services_by_name["ConfigService"] = _CONFIGSERVICE

# @@protoc_insertion_point(module_scope)
