# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_helper/api/server.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grpc_helper.api import common_pb2 as grpc__helper_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grpc_helper/api/server.proto",
    package="",
    syntax="proto3",
    serialized_options=b"\n\017grpc_helper.apiP\001",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x1cgrpc_helper/api/server.proto\x1a\x1cgrpc_helper/api/common.proto"\xa2\x01\n\x0bServiceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1b\n\x13\x63urrent_api_version\x18\x03 \x01(\r\x12\x1d\n\x15supported_api_version\x18\x04 \x01(\r\x12\x10\n\x08is_proxy\x18\x05 \x01(\x08\x12\x12\n\nproxy_host\x18\x06 \x01(\t\x12\x12\n\nproxy_port\x18\x07 \x01(\r"C\n\x10MultiServiceInfo\x12\x12\n\x01r\x18\x01 \x01(\x0b\x32\x07.Result\x12\x1b\n\x05items\x18\x02 \x03(\x0b\x32\x0c.ServiceInfo""\n\x0fShutdownRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05"R\n\x14ProxyRegisterRequest\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\r*`\n\x10ServerApiVersion\x12\x16\n\x12SERVER_API_UNKNOWN\x10\x00\x12\x18\n\x14SERVER_API_SUPPORTED\x10\x01\x12\x16\n\x12SERVER_API_CURRENT\x10\x01\x1a\x02\x10\x01\x32\xc3\x01\n\x10RpcServerService\x12"\n\x04info\x12\x07.Filter\x1a\x11.MultiServiceInfo\x12+\n\x08shutdown\x12\x10.ShutdownRequest\x1a\r.ResultStatus\x12\x36\n\x0eproxy_register\x12\x15.ProxyRegisterRequest\x1a\r.ResultStatus\x12&\n\x0cproxy_forget\x12\x07.Filter\x1a\r.ResultStatusB\x13\n\x0fgrpc_helper.apiP\x01\x62\x06proto3',
    dependencies=[
        grpc__helper_dot_api_dot_common__pb2.DESCRIPTOR,
    ],
)

_SERVERAPIVERSION = _descriptor.EnumDescriptor(
    name="ServerApiVersion",
    full_name="ServerApiVersion",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SERVER_API_UNKNOWN", index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="SERVER_API_SUPPORTED", index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name="SERVER_API_CURRENT", index=2, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=b"\020\001",
    serialized_start=416,
    serialized_end=512,
)
_sym_db.RegisterEnumDescriptor(_SERVERAPIVERSION)

ServerApiVersion = enum_type_wrapper.EnumTypeWrapper(_SERVERAPIVERSION)
SERVER_API_UNKNOWN = 0
SERVER_API_SUPPORTED = 1
SERVER_API_CURRENT = 1


_SERVICEINFO = _descriptor.Descriptor(
    name="ServiceInfo",
    full_name="ServiceInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="ServiceInfo.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="ServiceInfo.version",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="current_api_version",
            full_name="ServiceInfo.current_api_version",
            index=2,
            number=3,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="supported_api_version",
            full_name="ServiceInfo.supported_api_version",
            index=3,
            number=4,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_proxy",
            full_name="ServiceInfo.is_proxy",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="proxy_host",
            full_name="ServiceInfo.proxy_host",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="proxy_port",
            full_name="ServiceInfo.proxy_port",
            index=6,
            number=7,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=63,
    serialized_end=225,
)


_MULTISERVICEINFO = _descriptor.Descriptor(
    name="MultiServiceInfo",
    full_name="MultiServiceInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="r",
            full_name="MultiServiceInfo.r",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="items",
            full_name="MultiServiceInfo.items",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=227,
    serialized_end=294,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
    name="ShutdownRequest",
    full_name="ShutdownRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="timeout",
            full_name="ShutdownRequest.timeout",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=296,
    serialized_end=330,
)


_PROXYREGISTERREQUEST = _descriptor.Descriptor(
    name="ProxyRegisterRequest",
    full_name="ProxyRegisterRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="names",
            full_name="ProxyRegisterRequest.names",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="ProxyRegisterRequest.version",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="host",
            full_name="ProxyRegisterRequest.host",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="port",
            full_name="ProxyRegisterRequest.port",
            index=3,
            number=4,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=332,
    serialized_end=414,
)

_MULTISERVICEINFO.fields_by_name["r"].message_type = grpc__helper_dot_api_dot_common__pb2._RESULT
_MULTISERVICEINFO.fields_by_name["items"].message_type = _SERVICEINFO
DESCRIPTOR.message_types_by_name["ServiceInfo"] = _SERVICEINFO
DESCRIPTOR.message_types_by_name["MultiServiceInfo"] = _MULTISERVICEINFO
DESCRIPTOR.message_types_by_name["ShutdownRequest"] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name["ProxyRegisterRequest"] = _PROXYREGISTERREQUEST
DESCRIPTOR.enum_types_by_name["ServerApiVersion"] = _SERVERAPIVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceInfo = _reflection.GeneratedProtocolMessageType(
    "ServiceInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _SERVICEINFO,
        "__module__": "grpc_helper.api.server_pb2"
        # @@protoc_insertion_point(class_scope:ServiceInfo)
    },
)
_sym_db.RegisterMessage(ServiceInfo)

MultiServiceInfo = _reflection.GeneratedProtocolMessageType(
    "MultiServiceInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _MULTISERVICEINFO,
        "__module__": "grpc_helper.api.server_pb2"
        # @@protoc_insertion_point(class_scope:MultiServiceInfo)
    },
)
_sym_db.RegisterMessage(MultiServiceInfo)

ShutdownRequest = _reflection.GeneratedProtocolMessageType(
    "ShutdownRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SHUTDOWNREQUEST,
        "__module__": "grpc_helper.api.server_pb2"
        # @@protoc_insertion_point(class_scope:ShutdownRequest)
    },
)
_sym_db.RegisterMessage(ShutdownRequest)

ProxyRegisterRequest = _reflection.GeneratedProtocolMessageType(
    "ProxyRegisterRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PROXYREGISTERREQUEST,
        "__module__": "grpc_helper.api.server_pb2"
        # @@protoc_insertion_point(class_scope:ProxyRegisterRequest)
    },
)
_sym_db.RegisterMessage(ProxyRegisterRequest)


DESCRIPTOR._options = None
_SERVERAPIVERSION._options = None

_RPCSERVERSERVICE = _descriptor.ServiceDescriptor(
    name="RpcServerService",
    full_name="RpcServerService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=515,
    serialized_end=710,
    methods=[
        _descriptor.MethodDescriptor(
            name="info",
            full_name="RpcServerService.info",
            index=0,
            containing_service=None,
            input_type=grpc__helper_dot_api_dot_common__pb2._FILTER,
            output_type=_MULTISERVICEINFO,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="shutdown",
            full_name="RpcServerService.shutdown",
            index=1,
            containing_service=None,
            input_type=_SHUTDOWNREQUEST,
            output_type=grpc__helper_dot_api_dot_common__pb2._RESULTSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="proxy_register",
            full_name="RpcServerService.proxy_register",
            index=2,
            containing_service=None,
            input_type=_PROXYREGISTERREQUEST,
            output_type=grpc__helper_dot_api_dot_common__pb2._RESULTSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="proxy_forget",
            full_name="RpcServerService.proxy_forget",
            index=3,
            containing_service=None,
            input_type=grpc__helper_dot_api_dot_common__pb2._FILTER,
            output_type=grpc__helper_dot_api_dot_common__pb2._RESULTSTATUS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_RPCSERVERSERVICE)

DESCRIPTOR.services_by_name["RpcServerService"] = _RPCSERVERSERVICE

# @@protoc_insertion_point(module_scope)
